@@ -18,7 +18,7 @@ use Encode qw(encode decode);
 use Carp qw(carp croak );
 
 use vars qw'$VERSION %link_spec';
-$VERSION = '0.52';
+$VERSION = '0.53';
 
 =head1 NAME
 
@@ -2074,7 +2074,7 @@ sub selector {
     if ('ARRAY' ne (ref $query || '')) {
         $query = [$query];
     };
-    my @q = map { selector_to_xpath($_); } @$query;
+    my @q = map { selector_to_xpath($_) } @$query;
     $self->xpath(\@q, %options);
 };
 
@@ -2407,7 +2407,9 @@ sub form_with_fields {
     if (ref $fields[0] eq 'HASH') {
         $options = shift @fields;
     };
-    my @clauses = map { sprintf './/input[@name="%s"]', quote_xpath($_) } @fields;
+    my @clauses  = map { $self->application->element_query([qw[input select textarea]], { 'name' => $_ })} @fields;
+    
+    
     my $q = "//form[" . join( " and ", @clauses)."]";
     #warn $q;
     _default_limiter( single => $options );
@@ -2541,16 +2543,8 @@ sub _field_by_name {
         @fields = $name;
     } else {
         _default_limiter( single => \%options );
-        my $query = 
-            './/*[(' . 
-                join ' or ',
-                q{translate(local-name(.), "ABCDEFGHIJKLMNOPQRSTUVWXYZ", "abcdefghijklmnopqrstuvwxyz")="input"},
-                q{translate(local-name(.), "ABCDEFGHIJKLMNOPQRSTUVWXYZ", "abcdefghijklmnopqrstuvwxyz")="select"},
-                q{translate(local-name(.), "ABCDEFGHIJKLMNOPQRSTUVWXYZ", "abcdefghijklmnopqrstuvwxyz")="textarea"},
-            . ')'
-            . sprintf(  q{ and @%s="%s"]}, 
-                             $attr,  $name
-                   );
+        my $query = $self->application->element_query([qw[input select textarea]], { $attr => $name });
+        #warn $query;
         @fields = $self->xpath($query,%options);
     };
     @fields
